@@ -58,10 +58,10 @@ tiledb_query_type <- function(query) {
 #'
 #' @param query A TileDB Query object
 #' @param layout A character variable with the layout; must be one of
-#'   "ROW_MAJOR", "COL_MAJOR", "GLOBAL_ORDER", "UNORDERED")
+#'   "COL_MAJOR", "ROW_MAJOR", "GLOBAL_ORDER", "UNORDERED")
 #' @return The modified query object, invisibly
 #' @export
-tiledb_query_set_layout <- function(query, layout=c("ROW_MAJOR", "COL_MAJOR",
+tiledb_query_set_layout <- function(query, layout=c("COL_MAJOR", "ROW_MAJOR",
                                                     "GLOBAL_ORDER", "UNORDERED")) {
   layout <- match.arg(layout)
   stopifnot(query_object=is(query, "tiledb_query"))
