@@ -1,6 +1,6 @@
 #  MIT License
 #
-#  Copyright (c) 2017-2020 TileDB Inc.
+#  Copyright (c) 2017-2021 TileDB Inc.
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -30,3 +30,11 @@
   ## similarly, use a slot for the vfs object
   .pkgenv[["vfs"]] <- NULL
 }
+
+.onAttach <- function(libname, pkgName) {
+    if (interactive()) {
+        packageStartupMessage("TileDB R ", packageVersion("tiledb"),
+                              " with TileDB Embedded ", format(tiledb_version(TRUE)),
+                              ". See https://tiledb.com for more information.")
+    }
+}
