@@ -1128,3 +1128,71 @@ M <- matrix(runif(N*K), N, K)
 obj[] <- M                              # prior to #246 this write had a write data type
 chk <- tiledb_array(uri, as.matrix=TRUE)
 expect_equal(chk[], M)
+
+
+## test for data.frame append
+if (!requireNamespace("palmerpenguins", quietly=TRUE)) exit_file("remainder needs 'palmerpenguins'")
+library(palmerpenguins)
+uri <- tempfile()
+fromDataFrame(penguins, uri, sparse = TRUE,
+              col_index = c("species", "year"),
+              tile_domain=list(year=c(1966L, 2021L)))
+arr <- tiledb_array(uri, as.data.frame=TRUE)
+## new data
+newdf <- penguins[1:2,]
+newdf$species <- c("Fred", "Ginger")
+newdf$island <- c("Manhattan", "Staten Island")
+newdf$year <- c(1966L, 1969L)                     # int is important
+arr[] <- newdf
+## check it
+chk <- tiledb_array(uri, as.data.frame=TRUE)
+res <- chk[]
+expect_true(1966L %in% res$year)
+expect_true(1969L %in% res$year)
+expect_true("Manhattan" %in% res$island)
+expect_true("Staten Island" %in% res$island)
+expect_true("Fred" %in% res$species)
+expect_true("Ginger" %in% res$species)
+expect_equal(nrow(penguins) + 2, nrow(res))
+expect_equal(ncol(penguins), ncol(res))
+
+## test for both possible orders of selected_ranges
+selected_ranges(arr) <- list(year=cbind(1966L, 1999L),
+                             species=matrix(c("Fred", "Fred",
+                                              "Ginger", "Ginger"),
+                                            2, 2, byrow=TRUE))
+res1 <- arr[]
+expect_equal(nrow(res1), 2)
+selected_ranges(arr) <- list(species=matrix(c("Fred", "Fred",
+                                              "Ginger", "Ginger"),
+                                            2, 2, byrow=TRUE),
+                             year=cbind(1966L, 1999L))
+res2 <- arr[]
+expect_equal(nrow(res2), 2)
+expect_equal(res1, res2)
+
+
+
+## issue 255
+uri <- tempfile()
+## Generate a matrix
+n <- 5L
+k <- 4L
+mat <- matrix(1:(n*k) * 0.12345, nrow=n, ncol=k)
+dom <- tiledb_domain(dims = c(tiledb_dim("rows", c(1L, n), n, "INT32"),
+                              tiledb_dim("cols", c(1L, k), k, "INT32")))
+schema <- tiledb_array_schema(dom, attrs=tiledb_attr("vals", type="FLOAT64"))
+tiledb_array_create(uri, schema)
+arr <- tiledb_array(uri, is.sparse=FALSE)
+I <- c(1:3)
+J <- c(3:4)
+arr[I, J] <- mat[I, J]
+I <- 4:5
+J <- 1:4
+arr[I,J] <- mat[I, J]
+arr2 <- tiledb_array(uri, as.matrix=TRUE)
+res <- arr2[]
+expect_equal(dim(res), c(5,4))
+expect_equal(sum(is.na(res[1:3,1:2])), 6) # arr[1:3,1:2] all NA
+expect_equal(res[1:3,3:4], mat[1:3,3:4])
+expect_equal(res[4:5,1:4], mat[4:5,1:4])
